<?php

namespace Concrete\Package\AbShowHideLink\Block\AbShowHideLink;

use Concrete\Core\Editor\LinkAbstractor;

/**
 * ab_show_hide_link package for Concrete5
 * Copyright Copyright 2018-2019, Alex Borisov
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_show_hide_link
 */

class Controller extends \Concrete\Core\Block\BlockController
{
    
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceWidth = "600";
    protected $btInterfaceHeight = "400";
    protected $btTable = 'btAbShowHideLink';
    protected $btDefaultSet = 'basic';
    
    public function getBlockTypeDescription() 
    {
        return t("Add Show/Hide Link block");
    }

    public function getBlockTypeName() 
    {
        return t("Show/Hide Link");
    }

    public function on_start() {
        $this->set('app', $this->app);
    }
    
    public function registerViewAssets($outputContent = '')
    {
        $this->requireAsset('javascript', 'jquery');
        $this->requireAsset('css', 'font-awesome');
    }
    
    public function view() 
    {
        $this->set('text_show', LinkAbstractor::translateFrom($this->text_show));
        $this->set('text_hide', LinkAbstractor::translateFrom($this->text_hide));
        
        $data = array(
            'link_text_show' => $this->link_text_show,
            'link_text_hide' => $this->link_text_hide,
            'truncate' => $this->truncate ? true : false,
            'fade_speed' => $this->fade_speed,
        );
        $this->set('data', json_encode($data, JSON_UNESCAPED_UNICODE));
    }

    public function edit()
    {
        $this->set('text_show', LinkAbstractor::translateFrom($this->text_show));
        $this->set('text_hide', LinkAbstractor::translateFrom($this->text_hide));
    }
    
    public function save($args) 
    {
        $service = $this->app->make('helper/security');
        $args['plain_text'] = isset($args['plain_text']) ? $service->sanitizeString($args['plain_text']) : '';
        $args['text_show'] = LinkAbstractor::translateTo($args['text_show']);
        $args['text_hide'] = LinkAbstractor::translateTo($args['text_hide']);
        $args['truncate'] = isset($args['truncate']) ? 1 : 0;
        $args['num_char'] = isset($args['num_char']) && isset($args['truncate']) ? (int)$args['num_char'] : 0;
        $args['fade_speed'] = isset($args['fade_speed']) ? (int)$args['fade_speed'] : 0;
        parent::save($args);
    }

    public function getTextShow()
    {
        return LinkAbstractor::translateFromEditMode($this->text_show);
    }

    public function getTextHide()
    {
        return LinkAbstractor::translateFromEditMode($this->text_hide);
    }
     
}
