<?php 
defined('C5_EXECUTE') or die("Access Denied.");

/**
 * ab_show_hide_link package for Concrete5
 * Copyright Copyright 2018-2019, Alex Borisov
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_show_hide_link
 */

$editor = $app->make('editor');
?>

<style>
.ab-show-hide-link-form .text-muted {
    font-size: 0.8em;
}

.ab-show-hide-link-form .hidden {
    display: none !important;
    visibility: hidden !important;
}
</style>

<fieldset class="ab-show-hide-link-form">

    <div class="form-group">
        <div class="checkbox" data-checkbox-wrapper="truncate">
            <label>
                <?php
                echo $form->checkbox('truncate', 1, $truncate);
                echo t('Truncate shown text');
                ?>
            </label>
        </div>
        <div data-fields="truncate" style="display: none;">
            <div class="well">
                <div class="form-group">
                    <?php 
                    echo $form->label('plain_text', t('Plain text to show'));
                    echo $form->textarea('plain_text', $plain_text, ['rows'=>"10", 'maxlength' => 65535]);
                    echo '<p class="text-muted">' . t('Max 65535 symbols') . '</p>';
                    ?>
                </div>
                <div class="form-group">
                    <?php
                    echo $form->label('num_char', t('Number of characters to truncate'));
                    echo $form->number('num_char', $num_char ? $num_char : 0, ['min' => '0', 'max' => '65535', 'class' => "decimals"]);
                    echo '<p class="text-muted">' . t('Values from 0 to 65535') . '</p>';
                    ?>
                </div>
            </div>
        </div>
    </div>
    
    <div class="form-group text-to-hide">
        <?php 
        echo $form->label('text_show', t('Text to show'));
        echo $editor->outputBlockEditModeEditor('text_show', $controller->getTextShow());
        echo '<p class="text-muted">' . t('Max 65535 symbols') . '</p>';
        ?>
    </div>

    <div class="form-group text-to-hide">
        <?php 
        echo $form->label('text_hide', t('Text to hide (to show later on click)'));
        echo $editor->outputBlockEditModeEditor('text_hide', $controller->getTextHide());
        echo '<p class="text-muted">' . t('Max 65535 symbols') . '</p>';
        ?>
    </div>

    <div class="form-group">
        <?php
        echo $form->label('link_text_show', t('Show link text'));
        echo $form->text('link_text_show', $link_text_show ? $link_text_show : t('Show'), ['maxlength' => 256]);
        echo '<p class="text-muted">' . t('Max 256 symbols') . '</p>';
        ?>
    </div>
    
    <div class="form-group">
        <?php
        echo $form->label('link_text_hide', t('Hide link text'));
        echo $form->text('link_text_hide', $link_text_hide ? $link_text_hide : t('Hide'), ['maxlength' => 256]);
        echo '<p class="text-muted">' . t('Max 256 symbols') . '</p>';
        ?>
    </div>
    
    <div class="form-group">
        <?php
        echo $form->label('fade_speed', t('Text show/hide fade speed'));
        echo $form->number('fade_speed', $fade_speed ? $fade_speed : 0, ['min' => '0', 'max' => '10000', 'class' => "decimals"]);
        echo '<p class="text-muted">' . t('Values from 0 to 10000 (in miliseconds)') . '</p>';
        ?>
    </div>
</fieldset>

<script type="text/javascript">
$(function(){
    $('.decimals').keydown(function (e) {
        // Allow: backspace, delete, tab, escape, enter and .
        if ($.inArray(e.keyCode, [46, 8, 9, 27, 13, 110, 190]) !== -1 ||
             // Allow: Ctrl+A, Command+A
            (e.keyCode === 65 && (e.ctrlKey === true || e.metaKey === true)) || 
             // Allow: home, end, left, right, down, up
            (e.keyCode >= 35 && e.keyCode <= 40)) {
                 // let it happen, don't do anything
                 return;
        }
        // Ensure that it is a number and stop the keypress
        if ((e.shiftKey || (e.keyCode < 48 || e.keyCode > 57)) && (e.keyCode < 96 || e.keyCode > 105)) {
            e.preventDefault();
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Oops')); ?>,
                message: <?php echo json_encode(t('Numbers only!')); ?>
            });
        }
    });
    $('#ccm-form-submit-button').on('click', function(e){
        var plain_text = $('textarea[name="plain_text"]').val();
        var text_show = $('textarea[name="text_show"]').val();
        var text_hide = $('textarea[name="text_hide"]').val();
        var link_text_show = $.trim($('#link_text_show').val());
        var link_text_hide = $.trim($('#link_text_hide').val());
        var truncate = $('#truncate').is(':checked');
        var num_char = parseInt($.trim($('#num_char').val()));
        var fade_speed = parseInt($.trim($('#fade_speed').val()));
        
        if (text_show.length > 65535 || text_hide.length > 65535) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Text value error:')); ?>,
                message: <?php echo json_encode(t('Text must have max 65535 characters')); ?>
            });
        }
        else if (!truncate && !(text_show.length > 0 || text_hide.length > 0)) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Text value error:')); ?>,
                message: <?php echo json_encode(t('Both texts cannot be empty')); ?>
            });
        }
        else if (link_text_show.length > 256 || link_text_hide.length > 256) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Text value error:')); ?>,
                message: <?php echo json_encode(t('Text must have max 256 characters')); ?>
            });
        }
        else if (truncate && (!plain_text.length > 0 || plain_text.length > 65535)) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Text value error:')); ?>,
                message: <?php echo json_encode(t('Plain text cannot be empty and must have max 65535 characters')); ?>
            });
        }
        else if (truncate && (num_char < 0 || num_char > 65535)) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Truncate value error:')); ?>,
                message: <?php echo json_encode(t('Truncate value must be from 0 to 65535')); ?>
            });
        }
        else if (fade_speed < 0 || fade_speed > 10000) {
            e.preventDefault();  // stop form from submitting
            e.stopPropagation(); // stop anything else from listening to our event and screwing things up
            ConcreteAlert.error({
                title: <?php echo json_encode(t('Fade speed value error:')); ?>,
                message: <?php echo json_encode(t('Fade speed value must be from 0 to 10000')); ?>
            });
        }
    });
    
    $('#truncate').on('change', function() {
        $('div[data-fields=truncate]').toggle($(this).is(':checked'));

        if (!$(this).is(':checked')) {
            $('#plain_text').val('');
            $('#num_char').val('');
            $('.text-to-show').removeClass('hidden');
            $('.text-to-hide').removeClass('hidden');
        }
        else {
            $('textarea[name="text_show"]').val('');
            $('textarea[name="text_hide"]').val('');
            $('.text-to-show').addClass('hidden');
            $('.text-to-hide').addClass('hidden');
        }
    }).trigger('change');
});
</script>
